@@ -138,6 +138,7 @@ def PlotLines(
     color="colorwheel",
     legend="_nolegend_",
     alpha=0.5,
+    loops=True,
     Info=[],
     selectList=[],
     parameter="",
@@ -183,6 +184,15 @@ def PlotLines(
     colortmp = "colorwheel"
 
 
+    if loops == True:            
+        pipelist=[]
+        doublette_list=[]
+        for pipe in elements:
+            doubles=pipelist.count((pipe[0],pipe[1]))
+            pipelist.append((pipe[0],pipe[1]))
+            doublette_list.append(doubles)                
+
+
     for count, element in enumerate(elements):
         if element in selectList or selectList == []:
             x, y = element[0], element[1]
@@ -220,19 +230,36 @@ def PlotLines(
          #       color_setting=c[count]
          #       linewidth_setting=linethicknesses[count]
          #       
-               
+            if loops==False:   
 
-            l = lines.Line2D(
-                x,
-                y,
-                color=color_setting,
-                linewidth=linewidth_setting,
-                label=legend,
-                alpha=alpha,
-                linestyle=linestyle,
-                picker=True,
-                pickradius=5
-            )
+                l = lines.Line2D(
+                    x,
+                    y,
+                    color=color_setting,
+                    linewidth=linewidth_setting,
+                    label=legend,
+                    alpha=alpha,
+                    linestyle=linestyle,
+                    picker=True,
+                    pickradius=5
+                )
+
+            else:                           
+                Color_list=["k","b","g","r","c","m","y"]                
+                l = lines.Line2D(
+                    x,
+                    y,
+                    color=Color_list[doublette_list[count]],
+                    linewidth=linewidth_setting,
+                    label=legend,
+                    alpha=alpha,
+                    linestyle=linestyle,
+                    picker=True,
+                    pickradius=5
+                )
+
+
+                
 
             l.url = element[2]
             ax.add_line(l)
@@ -250,16 +277,30 @@ def PlotLines(
 
     param_list = ["max_pressure_bar","pressure_bar", "diameter_mm", "max_cap_M_m3_per_d"]
 
-    if parameter in param_list:
-        cbaxes = fig.add_axes([0.123, 0.05, 0.777, 0.008])
-        if entrycheck!=[]:
-            fig.colorbar(
-                matplotlib.cm.ScalarMappable(norm=norm, cmap=cmap),
-                cax=cbaxes,
-                orientation="horizontal",
-                label=parameter,
-            )
+    if loops==False:
+        if parameter in param_list:
+            cbaxes = fig.add_axes([0.123, 0.05, 0.777, 0.008])
+            if entrycheck!=[]:
+                fig.colorbar(
+                    matplotlib.cm.ScalarMappable(norm=norm, cmap=cmap),
+                    cax=cbaxes,
+                    orientation="horizontal",
+                    label=parameter,
+                )
 
+    if loops==True:
+       
+       loops_legend=[lines.Line2D([0],[0],color=Color_list[i],
+                     lw=3,label=str(i+1)) for i in set(doublette_list)]
+
+
+       # [lines.Line2D([0],[0],color="k",lw=4,label='1'),
+             # lines.Line2D([0],[0],color="r",lw=4,label='2')]
+
+       leg1=ax.legend()
+       leg2=ax.legend(handles=loops_legend,loc='lower right',title='Line-Count')      
+       ax.add_artist(leg1)
+    
     return
 
 
@@ -318,6 +359,7 @@ def quickplot(
     SingleLabel="",
     SingleSize="",
     SingleAlpha="",
+    loops=False,
     SingleLineStyle="solid",
     savefile="",
     PlotList=[],
@@ -365,6 +407,9 @@ def quickplot(
     Fig                 matplotlib fig-object, the return value of quickplot() can be used to print on top of the last plot
     hold                boolean, if true quickplot will not plot
 
+    Options
+    ------------
+    loops               boolean, show double pipelines in color default[False]
 
     Single Style Object
     -----------------
@@ -516,7 +561,8 @@ def quickplot(
                             linestyle=SingleLineStyle,
                             linewidth=int(SingleLineWidth),
                             cursor_data=cursor_data,
-                            Cursor_Lines=Cursor_Lines,
+                            Cursor_Lines=Cursor_Lines,#
+                            loops=loops,
                             alpha=alpha,
                             color=color,
                             legend=LegendString,
@@ -672,6 +718,7 @@ def quickplot(
                             linewidth=int(SingleLineWidth),
                             linestyle=SingleLineStyle,
                             alpha=alpha,
+                            loops=loops,
                             color=color,
                             legend=LegendString,
                             Info=Info,
